<?php

/**
 * @file
 * Helper functions.
 */

/**
 * Return the drush command help html.
 *
 * @return string
 *   The drush command help html.
 */
function _drush_help_drush_get_drush_command_help($drush_commands) {
  // Adding the Drush commands section.
  $section['drush_help'] = ['#markup' => '<h3>' . t('Drush commands') . '</h3>'];

  foreach ($drush_commands as $command => $definition) {
    // The details drush command element container.
    $section[$command] = array(
      '#type' => 'fieldset',
      '#title' => $command,
      '#description' => $definition['description'],
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
      '#attached' => array(
        'library' => array(
          array('system', 'drupal.collapse'),
        ),
      ),
      '#attributes' => array(
        'class' => array('collapsible', 'collapsed', 'drush_help'),
      ),
    );

    // Read more about the empty class attribute in HTML at:
    // https://stackoverflow.com/q/30748847/3653989 .
    $class = array();
    if (module_exists('responsive_tables')) {
      $class[] = RESPONSIVE_PRIORITY_MEDIUM;
    }

    // Examples.
    if (isset($definition['examples'])) {
      $rows = array();
      // Iterating over each example.
      foreach ($definition['examples'] as $example_command => $section_definition) {
        $rows[] = array($example_command, $section_definition);
      }
      // Examples render array.
      $section[$command]['examples'] = array(
        '#theme' => 'table',
        '#caption' => t('Examples'),
        '#header' => array(
          t('Command'),
          array(
            'data' => t('Description'),
            // Hidding the description on narrow width devices.
            'class' => $class,
          ),
        ),
        '#rows' => $rows,
      );
    }

    // Arguments.
    if (isset($definition['arguments'])) {
      $rows = array();
      // Iterating over each argument.
      foreach ($definition['arguments'] as $example_command => $section_definition) {
        // Sometimes we can have links in the drush descriptions, so we need to
        // extract it and convert it in links (in the Drupal way) to be
        // displayed in the Drupal interface.
        // Searching if the description have links inside to convert it.
        $section_definition = _drush_help_convert_plain_url_in_link($section_definition);

        $rows[] = array($example_command, $section_definition);
      }
      // Arguments render array.
      $section[$command]['arguments'] = array(
        '#theme' => 'table',
        '#caption' => t('Arguments'),
        '#header' => array(
          t('Name'),
          array(
            'data' => t('Description'),
            // Hidding the description on narrow width devices.
            'class' => $class,
          ),
        ),
        '#rows' => $rows,
      );
    }

    // Options.
    if (isset($definition['options'])) {
      $rows = array();
      // Iterating over each option.
      foreach ($definition['options'] as $example_command => $section_definition) {
        $example_command = '--' . $example_command;
        // Verifying that we have example-value.
        if (isset($section_definition['example-value'])) {
          // Checking for the value.
          switch ($section_definition['value']) {
            case 'optional':
              $example_command .= '=[' . $section_definition['example-value'] . ']';
              break;

            // By default is required.
            default:
              $example_command .= '=<' . $section_definition['example-value'] . '>';
          }
        }

        // Sometimes we can have links in the drush descriptions, so we need to
        // extract it and convert it in links (in the Drupal way) to be
        // displayed in the Drupal interface.
        // Searching if the description have links inside to convert it.
        $section_definition['description'] = _drush_help_convert_plain_url_in_link($section_definition['description']);

        $rows[] = array($example_command, $section_definition['description']);
      }
      // Options render array.
      $section[$command]['options'] = array(
        '#theme' => 'table',
        '#caption' => t('Options'),
        '#header' => array(
          t('Name'),
          array(
            'data' => t('Description'),
            // Hidding the description on narrow width devices.
            'class' => $class,
          ),
        ),
        '#rows' => $rows,
      );
    }

    // Alias.
    if (isset($definition['aliases'])) {
      $rows = array();
      // Iterating over all the aliases.
      foreach ($definition['aliases'] as $alias) {
        $rows[] = $alias;
      }
      // Aliases render array.
      $section[$command][] = array(
        '#markup' => '<div class="aliases">' . t('Aliases') . '</div>',
      );
      // List of aliases.
      $section[$command]['aliases'] = array(
        '#markup' => '<div class="item-list--comma-list item-list">' . implode(', ', $rows) . '</div>',
      );
    }
  }
  // Attaching css styles.
  $section[$command]['aliases']['#attached']['css'][] = drupal_get_path('module', 'drush_help') . '/css/help_page.css';
  // Rendering all the elements.
  $drush_command_html = drupal_render($section);

  return $drush_command_html;
}

/**
 * Convert plain url to links in a given string.
 *
 * @param string $string
 *   The string to review.
 *
 * @return string
 *   The new string.
 */
function _drush_help_convert_plain_url_in_link($string) {
  // Creating the filter.
  $filter = new stdClass();
  // Adding the filter settings.
  $filter->settings = array(
    'filter_url_length' => 496,
  );

  // Applying the filter.
  $result = _filter_url($string, $filter);

  return $result;
}
